@@ -156,7 +156,7 @@ def _check_path_header(req, name, length, error_msg):
     :param length: length of path segment check
     :param error_msg: error message for client
     :returns: A tuple with path parts according to length
-    :raise: HTTPPreconditionFailed if header value
+    :raise HTTPPreconditionFailed: if header value
             is not well formatted.
     """
     src_header = unquote(req.headers.get(name))
@@ -178,7 +178,7 @@ def _check_copy_from_header(req):
 
     :param req: HTTP request object
     :returns: A tuple with container name and object name
-    :raise: HTTPPreconditionFailed if x-copy-from value
+    :raise HTTPPreconditionFailed: if x-copy-from value
             is not well formatted.
     """
     return _check_path_header(req, 'X-Copy-From', 2,
@@ -194,7 +194,7 @@ def _check_destination_header(req):
 
     :param req: HTTP request object
     :returns: A tuple with container name and object name
-    :raise: HTTPPreconditionFailed if destination value
+    :raise HTTPPreconditionFailed: if destination value
             is not well formatted.
     """
     return _check_path_header(req, 'Destination', 2,
@@ -413,9 +413,11 @@ class ServerSideCopyMiddleware(object):
             # which currently only happens because there are more than
             # CONTAINER_LISTING_LIMIT segments in a segmented object. In
             # this case, we're going to refuse to do the server-side copy.
+            close_if_possible(source_resp.app_iter)
             return HTTPRequestEntityTooLarge(request=req)
 
         if source_resp.content_length > MAX_FILE_SIZE:
+            close_if_possible(source_resp.app_iter)
             return HTTPRequestEntityTooLarge(request=req)
 
         return source_resp
@@ -459,7 +461,6 @@ class ServerSideCopyMiddleware(object):
         ssc_ctx = ServerSideCopyWebContext(self.app, self.logger)
         source_resp = self._get_source_object(ssc_ctx, source_path, req)
         if source_resp.status_int >= HTTP_MULTIPLE_CHOICES:
-            close_if_possible(source_resp.app_iter)
             return source_resp(source_resp.environ, start_response)
 
         # Create a new Request object based on the original request instance.
