@@ -426,7 +426,7 @@ def parse_add_value(add_value):
 
     :returns: dictionary with keys 'region', 'zone', 'ip', 'port', 'device',
         'replication_ip', 'replication_port', 'meta'
-    :raises: ValueError if add_value is malformed
+    :raises ValueError: if add_value is malformed
     """
     region = None
     rest = add_value
@@ -642,6 +642,15 @@ def dispersion_report(builder, search_filter=None, verbose=False):
     }
 
 
+def format_device(region=None, zone=None, ip=None, device=None, **kwargs):
+    """
+    Convert device dict or tier attributes to a representative string.
+
+    :returns: a string, the normalized format of a device tier
+    """
+    return "r%sz%s-%s/%s" % (region, zone, ip, device)
+
+
 def get_tier_name(tier, builder):
     if len(tier) == 1:
         return "r%s" % (tier[0], )
@@ -651,8 +660,8 @@ def get_tier_name(tier, builder):
         return "r%sz%s-%s" % (tier[0], tier[1], tier[2])
     if len(tier) == 4:
         device = builder.devs[tier[3]] or {}
-        return "r%sz%s-%s/%s" % (tier[0], tier[1], tier[2],
-                                 device.get('device', 'IDd%s' % tier[3]))
+        return format_device(tier[0], tier[1], tier[2], device.get(
+            'device', 'IDd%s' % tier[3]))
 
 
 def validate_device_name(device_name):
@@ -660,3 +669,7 @@ def validate_device_name(device_name):
         device_name.startswith(' ') or
         device_name.endswith(' ') or
         len(device_name) == 0)
+
+
+def pretty_dev(device):
+    return format_device(**device)
