@@ -17,6 +17,7 @@ import json
 import os
 import time
 import traceback
+import math
 from swift import gettext_ as _
 from xml.etree.cElementTree import Element, SubElement, tostring
 
@@ -139,7 +140,7 @@ class ContainerController(BaseStorageServer):
         Validate that the index supplied maps to a policy.
 
         :returns: policy index from request, or None if not present
-        :raises: HTTPBadRequest if the supplied index is bogus
+        :raises HTTPBadRequest: if the supplied index is bogus
         """
 
         policy_index = req.headers.get('X-Backend-Storage-Policy-Index', None)
@@ -433,7 +434,9 @@ class ContainerController(BaseStorageServer):
             if value != '' and (key.lower() in self.save_headers or
                                 is_sys_or_user_meta('container', key)))
         headers['Content-Type'] = out_content_type
-        return HTTPNoContent(request=req, headers=headers, charset='utf-8')
+        resp = HTTPNoContent(request=req, headers=headers, charset='utf-8')
+        resp.last_modified = math.ceil(float(headers['X-PUT-Timestamp']))
+        return resp
 
     def update_data_record(self, record):
         """
@@ -530,6 +533,7 @@ class ContainerController(BaseStorageServer):
             if not container_list:
                 return HTTPNoContent(request=req, headers=resp_headers)
             ret.body = '\n'.join(rec[0] for rec in container_list) + '\n'
+        ret.last_modified = math.ceil(float(resp_headers['X-PUT-Timestamp']))
         return ret
 
     @public
