@@ -15,7 +15,7 @@
 
 import unittest
 
-from swift.common.swob import Request
+from swift.common.swob import Request, HTTPMovedPermanently
 from swift.common.middleware import domain_remap
 from swift.common import utils
 
@@ -23,7 +23,15 @@ from swift.common import utils
 class FakeApp(object):
 
     def __call__(self, env, start_response):
-        return env['PATH_INFO']
+        start_response('200 OK', [])
+        return [env['PATH_INFO']]
+
+
+class RedirectSlashApp(object):
+
+    def __call__(self, env, start_response):
+        loc = env['PATH_INFO'] + '/'
+        return HTTPMovedPermanently(location=loc)(env, start_response)
 
 
 def start_response(*args):
@@ -40,36 +48,36 @@ class TestDomainRemap(unittest.TestCase):
                                           'SERVER_NAME': 'example.com'},
                             headers={'Host': None})
         resp = self.app(req.environ, start_response)
-        self.assertEqual(resp, '/')
+        self.assertEqual(resp, ['/'])
         req = Request.blank('/', environ={'REQUEST_METHOD': 'GET'},
                             headers={'Host': 'example.com'})
         resp = self.app(req.environ, start_response)
-        self.assertEqual(resp, '/')
+        self.assertEqual(resp, ['/'])
         req = Request.blank('/', environ={'REQUEST_METHOD': 'GET'},
                             headers={'Host': 'example.com:8080'})
         resp = self.app(req.environ, start_response)
-        self.assertEqual(resp, '/')
+        self.assertEqual(resp, ['/'])
 
     def test_domain_remap_account(self):
         req = Request.blank('/', environ={'REQUEST_METHOD': 'GET',
                                           'SERVER_NAME': 'AUTH_a.example.com'},
                             headers={'Host': None})
         resp = self.app(req.environ, start_response)
-        self.assertEqual(resp, '/v1/AUTH_a')
+        self.assertEqual(resp, ['/v1/AUTH_a/'])
         req = Request.blank('/', environ={'REQUEST_METHOD': 'GET'},
                             headers={'Host': 'AUTH_a.example.com'})
         resp = self.app(req.environ, start_response)
-        self.assertEqual(resp, '/v1/AUTH_a')
+        self.assertEqual(resp, ['/v1/AUTH_a/'])
         req = Request.blank('/', environ={'REQUEST_METHOD': 'GET'},
                             headers={'Host': 'AUTH-uuid.example.com'})
         resp = self.app(req.environ, start_response)
-        self.assertEqual(resp, '/v1/AUTH_uuid')
+        self.assertEqual(resp, ['/v1/AUTH_uuid/'])
 
     def test_domain_remap_account_container(self):
         req = Request.blank('/', environ={'REQUEST_METHOD': 'GET'},
                             headers={'Host': 'c.AUTH_a.example.com'})
         resp = self.app(req.environ, start_response)
-        self.assertEqual(resp, '/v1/AUTH_a/c')
+        self.assertEqual(resp, ['/v1/AUTH_a/c/'])
 
     def test_domain_remap_extra_subdomains(self):
         req = Request.blank('/', environ={'REQUEST_METHOD': 'GET'},
@@ -81,31 +89,53 @@ class TestDomainRemap(unittest.TestCase):
         req = Request.blank('/v1', environ={'REQUEST_METHOD': 'GET'},
                             headers={'Host': 'AUTH_a.example.com'})
         resp = self.app(req.environ, start_response)
-        self.assertEqual(resp, '/v1/AUTH_a')
+        self.assertEqual(resp, ['/v1/AUTH_a/'])
 
     def test_domain_remap_account_container_with_path_root(self):
         req = Request.blank('/v1', environ={'REQUEST_METHOD': 'GET'},
                             headers={'Host': 'c.AUTH_a.example.com'})
         resp = self.app(req.environ, start_response)
-        self.assertEqual(resp, '/v1/AUTH_a/c')
+        self.assertEqual(resp, ['/v1/AUTH_a/c/'])
+
+    def test_domain_remap_account_container_with_path_obj_slash_v1(self):
+        # Include http://localhost because urlparse used in Request.__init__
+        # parse //v1 as http://v1
+        req = Request.blank('http://localhost//v1',
+                            environ={'REQUEST_METHOD': 'GET'},
+                            headers={'Host': 'c.AUTH_a.example.com'})
+        resp = self.app(req.environ, start_response)
+        self.assertEqual(resp, ['/v1/AUTH_a/c//v1'])
+
+    def test_domain_remap_account_container_with_root_path_obj_slash_v1(self):
+        req = Request.blank('/v1//v1',
+                            environ={'REQUEST_METHOD': 'GET'},
+                            headers={'Host': 'c.AUTH_a.example.com'})
+        resp = self.app(req.environ, start_response)
+        self.assertEqual(resp, ['/v1/AUTH_a/c//v1'])
+
+    def test_domain_remap_account_container_with_path_trailing_slash(self):
+        req = Request.blank('/obj/', environ={'REQUEST_METHOD': 'GET'},
+                            headers={'Host': 'c.AUTH_a.example.com'})
+        resp = self.app(req.environ, start_response)
+        self.assertEqual(resp, ['/v1/AUTH_a/c/obj/'])
 
     def test_domain_remap_account_container_with_path(self):
         req = Request.blank('/obj', environ={'REQUEST_METHOD': 'GET'},
                             headers={'Host': 'c.AUTH_a.example.com'})
         resp = self.app(req.environ, start_response)
-        self.assertEqual(resp, '/v1/AUTH_a/c/obj')
+        self.assertEqual(resp, ['/v1/AUTH_a/c/obj'])
 
     def test_domain_remap_account_container_with_path_root_and_path(self):
         req = Request.blank('/v1/obj', environ={'REQUEST_METHOD': 'GET'},
                             headers={'Host': 'c.AUTH_a.example.com'})
         resp = self.app(req.environ, start_response)
-        self.assertEqual(resp, '/v1/AUTH_a/c/obj')
+        self.assertEqual(resp, ['/v1/AUTH_a/c/obj'])
 
     def test_domain_remap_account_matching_ending_not_domain(self):
         req = Request.blank('/dontchange', environ={'REQUEST_METHOD': 'GET'},
                             headers={'Host': 'c.aexample.com'})
         resp = self.app(req.environ, start_response)
-        self.assertEqual(resp, '/dontchange')
+        self.assertEqual(resp, ['/dontchange'])
 
     def test_domain_remap_configured_with_empty_storage_domain(self):
         self.app = domain_remap.DomainRemapMiddleware(FakeApp(),
@@ -113,7 +143,7 @@ class TestDomainRemap(unittest.TestCase):
         req = Request.blank('/test', environ={'REQUEST_METHOD': 'GET'},
                             headers={'Host': 'c.AUTH_a.example.com'})
         resp = self.app(req.environ, start_response)
-        self.assertEqual(resp, '/test')
+        self.assertEqual(resp, ['/test'])
 
     def test_storage_domains_conf_format(self):
         conf = {'storage_domain': 'foo.com'}
@@ -142,7 +172,7 @@ class TestDomainRemap(unittest.TestCase):
         req = Request.blank('/test', environ={'REQUEST_METHOD': 'GET'},
                             headers={'Host': 'c.prefix_uuid.example.com'})
         resp = self.app(req.environ, start_response)
-        self.assertEqual(resp, '/v1/PREFIX_uuid/c/test')
+        self.assertEqual(resp, ['/v1/PREFIX_uuid/c/test'])
 
     def test_domain_remap_configured_with_bad_prefixes(self):
         conf = {'reseller_prefixes': 'UNKNOWN'}
@@ -150,7 +180,7 @@ class TestDomainRemap(unittest.TestCase):
         req = Request.blank('/test', environ={'REQUEST_METHOD': 'GET'},
                             headers={'Host': 'c.prefix_uuid.example.com'})
         resp = self.app(req.environ, start_response)
-        self.assertEqual(resp, '/test')
+        self.assertEqual(resp, ['/test'])
 
     def test_domain_remap_configured_with_no_prefixes(self):
         conf = {'reseller_prefixes': ''}
@@ -158,7 +188,7 @@ class TestDomainRemap(unittest.TestCase):
         req = Request.blank('/test', environ={'REQUEST_METHOD': 'GET'},
                             headers={'Host': 'c.uuid.example.com'})
         resp = self.app(req.environ, start_response)
-        self.assertEqual(resp, '/v1/uuid/c/test')
+        self.assertEqual(resp, ['/v1/uuid/c/test'])
 
     def test_domain_remap_add_prefix(self):
         conf = {'default_reseller_prefix': 'FOO'}
@@ -166,7 +196,7 @@ class TestDomainRemap(unittest.TestCase):
         req = Request.blank('/test', environ={'REQUEST_METHOD': 'GET'},
                             headers={'Host': 'uuid.example.com'})
         resp = self.app(req.environ, start_response)
-        self.assertEqual(resp, '/v1/FOO_uuid/test')
+        self.assertEqual(resp, ['/v1/FOO_uuid/test'])
 
     def test_domain_remap_add_prefix_already_there(self):
         conf = {'default_reseller_prefix': 'AUTH'}
@@ -174,7 +204,7 @@ class TestDomainRemap(unittest.TestCase):
         req = Request.blank('/test', environ={'REQUEST_METHOD': 'GET'},
                             headers={'Host': 'auth-uuid.example.com'})
         resp = self.app(req.environ, start_response)
-        self.assertEqual(resp, '/v1/AUTH_uuid/test')
+        self.assertEqual(resp, ['/v1/AUTH_uuid/test'])
 
     def test_multiple_storage_domains(self):
         conf = {'storage_domain': 'storage1.com, storage2.com'}
@@ -186,13 +216,37 @@ class TestDomainRemap(unittest.TestCase):
             return self.app(req.environ, start_response)
 
         resp = do_test('auth-uuid.storage1.com')
-        self.assertEqual(resp, '/v1/AUTH_uuid/test')
+        self.assertEqual(resp, ['/v1/AUTH_uuid/test'])
 
         resp = do_test('auth-uuid.storage2.com')
-        self.assertEqual(resp, '/v1/AUTH_uuid/test')
+        self.assertEqual(resp, ['/v1/AUTH_uuid/test'])
 
         resp = do_test('auth-uuid.storage3.com')
-        self.assertEqual(resp, '/test')
+        self.assertEqual(resp, ['/test'])
+
+    def test_domain_remap_redirect(self):
+        app = domain_remap.DomainRemapMiddleware(RedirectSlashApp(), {})
+
+        req = Request.blank('/cont', environ={'REQUEST_METHOD': 'GET'},
+                            headers={'Host': 'auth-uuid.example.com'})
+        resp = req.get_response(app)
+        self.assertEqual(resp.status_int, 301)
+        self.assertEqual(resp.headers.get('Location'),
+                         'http://auth-uuid.example.com/cont/')
+
+        req = Request.blank('/cont/test', environ={'REQUEST_METHOD': 'GET'},
+                            headers={'Host': 'auth-uuid.example.com'})
+        resp = req.get_response(app)
+        self.assertEqual(resp.status_int, 301)
+        self.assertEqual(resp.headers.get('Location'),
+                         'http://auth-uuid.example.com/cont/test/')
+
+        req = Request.blank('/test', environ={'REQUEST_METHOD': 'GET'},
+                            headers={'Host': 'cont.auth-uuid.example.com'})
+        resp = req.get_response(app)
+        self.assertEqual(resp.status_int, 301)
+        self.assertEqual(resp.headers.get('Location'),
+                         'http://cont.auth-uuid.example.com/test/')
 
 
 class TestSwiftInfo(unittest.TestCase):
