@@ -26,7 +26,7 @@ from swift.common.ring.utils import (tiers_for_dev, build_tier_tree,
                                      validate_args, parse_args,
                                      parse_builder_ring_filename_args,
                                      build_dev_from_opts, dispersion_report,
-                                     parse_address)
+                                     parse_address, get_tier_name, pretty_dev)
 
 
 class TestUtils(unittest.TestCase):
@@ -664,11 +664,18 @@ class TestUtils(unittest.TestCase):
                     'ip': '127.0.0.3', 'port': 10003, 'device': 'sdd1'})
 
         # when the biggest tier has the smallest devices things get ugly
+        # can't move all the part-replicas in one rebalance
         rb.rebalance(seed=100)
         report = dispersion_report(rb, verbose=True)
-        self.assertEqual(rb.dispersion, 70.3125)
+        self.assertEqual(rb.dispersion, 9.375)
+        self.assertEqual(report['worst_tier'], 'r1z1-127.0.0.1')
+        self.assertEqual(report['max_dispersion'], 7.18562874251497)
+        # do a sencond rebalance
+        rb.rebalance(seed=100)
+        report = dispersion_report(rb, verbose=True)
+        self.assertEqual(rb.dispersion, 50.0)
         self.assertEqual(report['worst_tier'], 'r1z0-127.0.0.3')
-        self.assertEqual(report['max_dispersion'], 88.23529411764706)
+        self.assertEqual(report['max_dispersion'], 50.0)
 
         # ... but overload can square it
         rb.set_overload(rb.get_required_overload())
@@ -683,6 +690,21 @@ class TestUtils(unittest.TestCase):
         self.assertEqual(port, 6200)
         self.assertEqual(rest, 'R127.0.0.1:6200/sda1_some meta data')
 
+    def test_normalized_device_tier_names(self):
+        rb = ring.RingBuilder(8, 3, 0)
+        rb.add_dev({
+            'region': 1,
+            'zone': 1,
+            'ip': '127.0.0.1',
+            'port': 6011,
+            'device': 'd1',
+            'weight': 0.0,
+        })
+        dev = rb.devs[0]
+        expected = 'r1z1-127.0.0.1/d1'
+        self.assertEqual(expected, get_tier_name(tiers_for_dev(dev)[-1], rb))
+        self.assertEqual(expected, pretty_dev(dev))
+
 
 if __name__ == '__main__':
     unittest.main()
