@@ -362,12 +362,12 @@ class TestReconcilerUtils(unittest.TestCase):
             direct_head.side_effect = stub_resp_headers
             oldest_spi = reconciler.direct_get_container_policy_index(
                 self.fake_ring, 'a', 'con')
-        self.assertEqual(oldest_spi, None)
+        self.assertIsNone(oldest_spi)
 
     def test_get_container_policy_index_for_deleted(self):
         mock_path = 'swift.container.reconciler.direct_head_container'
         headers = container_resp_headers(
-            status_changed_at=Timestamp(time.time()).internal,
+            status_changed_at=Timestamp.now().internal,
             storage_policy_index=1,
         )
         stub_resp_headers = [
@@ -551,7 +551,7 @@ class TestReconcilerUtils(unittest.TestCase):
                 oldest_spi = reconciler.direct_get_container_policy_index(
                     self.fake_ring, 'a', 'con')
         # expired
-        self.assertEqual(oldest_spi, None)
+        self.assertIsNone(oldest_spi)
 
     def test_direct_delete_container_entry(self):
         mock_path = 'swift.common.direct_client.http_connect'
@@ -564,7 +564,7 @@ class TestReconcilerUtils(unittest.TestCase):
                 'partition': partition, 'method': method, 'path': path,
                 'headers': headers, 'query_string': query_string})
 
-        x_timestamp = Timestamp(time.time())
+        x_timestamp = Timestamp.now()
         headers = {'x-timestamp': x_timestamp.internal}
         fake_hc = fake_http_connect(200, 200, 200, give_connect=test_connect)
         with mock.patch(mock_path, fake_hc):
@@ -587,7 +587,7 @@ class TestReconcilerUtils(unittest.TestCase):
             socket.error(errno.ECONNREFUSED, os.strerror(errno.ECONNREFUSED)),
             ClientException(
                 'Container Server blew up',
-                '10.0.0.12', 6001, 'sdj', 404, 'Not Found'
+                '10.0.0.12', 6201, 'sdj', 404, 'Not Found'
             ),
         ]
         mock_direct_delete = mock.MagicMock()
@@ -597,7 +597,7 @@ class TestReconcilerUtils(unittest.TestCase):
                 mock.patch('eventlet.greenpool.DEBUG', False):
             rv = reconciler.direct_delete_container_entry(
                 self.fake_ring, 'a', 'c', 'o')
-        self.assertEqual(rv, None)
+        self.assertIsNone(rv)
         self.assertEqual(len(mock_direct_delete.mock_calls), 3)
 
     def test_add_to_reconciler_queue(self):
@@ -619,7 +619,6 @@ class TestReconcilerUtils(unittest.TestCase):
         self.assertTrue(ret)
         self.assertEqual(ret, str(int(5948918.63946 // 3600 * 3600)))
         self.assertEqual(len(connect_args), 3)
-        connect_args.sort(key=lambda a: (a['ipaddr'], a['port']))
 
         required_headers = ('x-content-type', 'x-etag')
 
@@ -657,7 +656,6 @@ class TestReconcilerUtils(unittest.TestCase):
         self.assertTrue(ret)
         self.assertEqual(ret, str(int(5948918.63946 // 3600 * 3600)))
         self.assertEqual(len(connect_args), 3)
-        connect_args.sort(key=lambda a: (a['ipaddr'], a['port']))
 
         required_headers = ('x-size', 'x-content-type')
 
@@ -1193,7 +1191,7 @@ class TestReconciler(unittest.TestCase):
 
     def test_src_object_unavailable_with_slightly_newer_tombstone(self):
         # should be some sort of retry case
-        q_ts = float(Timestamp(time.time()))
+        q_ts = float(Timestamp.now())
         container = str(int(q_ts // 3600 * 3600))
         q_path = '.misplaced_objects/%s' % container
         self._mock_listing({
@@ -1232,7 +1230,7 @@ class TestReconciler(unittest.TestCase):
 
     def test_src_object_unavailable_server_error(self):
         # should be some sort of retry case
-        q_ts = float(Timestamp(time.time()))
+        q_ts = float(Timestamp.now())
         container = str(int(q_ts // 3600 * 3600))
         q_path = '.misplaced_objects/%s' % container
         self._mock_listing({
@@ -1585,7 +1583,7 @@ class TestReconciler(unittest.TestCase):
         self.assertEqual(self.reconciler.stats['retry'], 1)
 
     def test_object_move_no_such_object_no_tombstone_recent(self):
-        q_ts = float(Timestamp(time.time()))
+        q_ts = float(Timestamp.now())
         container = str(int(q_ts // 3600 * 3600))
         q_path = '.misplaced_objects/%s' % container
 
@@ -1617,7 +1615,7 @@ class TestReconciler(unittest.TestCase):
         self.assertEqual(deleted_container_entries, [])
 
     def test_object_move_no_such_object_no_tombstone_ancient(self):
-        queue_ts = float(Timestamp(time.time())) - \
+        queue_ts = float(Timestamp.now()) - \
             self.reconciler.reclaim_age * 1.1
         container = str(int(queue_ts // 3600 * 3600))
 
